@@ -1,18 +1,19 @@
 # Copyright 2009-2015 Ram Rachum.
 # This program is distributed under the MIT license.
 
-'''
-This module defines the `OrderedDict` class.
-
-See its documentation for more information.
-'''
-
+from python_toolbox import sys_tools
 from python_toolbox import comparison_tools
 
 from collections import OrderedDict as StdlibOrderedDict
 
 
 class OrderedDict(StdlibOrderedDict):
+    '''
+    A dictionary with an order.
+    
+    This is a subclass of `collections.OrderedDict` with a couple of
+    improvements.
+    '''
     
     def move_to_end(self, key, last=True):
         '''Move an existing element to the end (or beginning if last==False).
@@ -21,22 +22,36 @@ class OrderedDict(StdlibOrderedDict):
         When last=True, acts like a fast version of self[key]=self.pop(key).
 
         '''
-        link = self.__map[key]
-        link_prev = link[0]
-        link_next = link[1]
-        link_prev[1] = link_next
-        link_next[0] = link_prev
-        root = self.__root
-        if last:
-            last = self.__root[0]
-            link[0] = last
-            link[1] = self.__root
-            last[1] = self.__root[0] = link
+        try:
+            self.__map
+        except AttributeError: # PyPy
+            if last:
+                self[key] = self.pop(key)
+            else:
+                # Very inefficient implementation for corner case.
+                value = self.pop(key)
+                items = tuple(self.items())
+                self.clear()
+                self[key] = value
+                self.update(items)
+            return
         else:
-            first = self.__root[1]
-            link[0] = self.__root
-            link[1] = first
-            root[1] = first[0] = link
+            link = self.__map[key]
+            link_prev = link[0]
+            link_next = link[1]
+            link_prev[1] = link_next
+            link_next[0] = link_prev
+            root = self.__root
+            if last:
+                last = self.__root[0]
+                link[0] = last
+                link[1] = self.__root
+                last[1] = self.__root[0] = link
+            else:
+                first = self.__root[1]
+                link[0] = self.__root
+                link[1] = first
+                root[1] = first[0] = link
             
 
     def sort(self, key=None, reverse=False):
