@@ -1,6 +1,8 @@
 # Copyright 2009-2015 Ram Rachum.
 # This program is distributed under the MIT license.
 
+from __future__ import division
+
 import re
 import pickle
 import abc
@@ -321,6 +323,21 @@ class BaseBagTestCase(cute_testing.TestCase):
         assert 3 * bag_1 == self.bag_type('bcc' * 3)
         assert 3 * bag_2 == self.bag_type('cddddd' * 3)
         
+        # We only allow floor division on bags, not regular divison, because a
+        # decimal bag is unheard of.
+        with cute_testing.RaiseAssertor(TypeError):
+            bag_0 / 2
+        with cute_testing.RaiseAssertor(TypeError):
+            bag_1 / 2
+        with cute_testing.RaiseAssertor(TypeError):
+            bag_2 / 2
+        with cute_testing.RaiseAssertor(TypeError):
+            bag_0 / self.bag_type('ab')
+        with cute_testing.RaiseAssertor(TypeError):
+            bag_1 / self.bag_type('ab')
+        with cute_testing.RaiseAssertor(TypeError):
+            bag_2 / self.bag_type('ab')
+        
         assert bag_0 // 2 == self.bag_type('bc')
         assert bag_1 // 2 == self.bag_type('c')
         assert bag_2 // 2 == self.bag_type('dd')
@@ -439,6 +456,10 @@ class BaseMutableBagTestCase(BaseBagTestCase):
         assert bag == self.bag_type('abracadabra' + 'a' * 5)
         assert bag is bag_reference
 
+        bag = bag_reference = self.bag_type('abracadabra')
+        with cute_testing.RaiseAssertor(TypeError):
+            bag['a'] /= 2 # Won't work because `bag['a']` happens to be odd.
+
         bag = bag_reference = self.bag_type('abracadabra')
         bag['a'] //= 2
         assert bag == self.bag_type('abracdbr')
@@ -479,6 +500,12 @@ class BaseMutableBagTestCase(BaseBagTestCase):
         assert bag == self.bag_type('abracadabra' * 2)
         assert bag is bag_reference
 
+        # We only allow floor division on bags, not regular divison, because a
+        # decimal bag is unheard of.
+        bag = bag_reference = self.bag_type('abracadabra')
+        with cute_testing.RaiseAssertor(TypeError):
+            bag /= 2
+
         bag = bag_reference = self.bag_type('abracadabra')
         bag //= 2
         assert bag == self.bag_type('aabr')
@@ -605,6 +632,8 @@ class BaseFrozenBagTestCase(BaseBagTestCase):
             bag['a'] -= 1
         with cute_testing.RaiseAssertor(TypeError):
             bag['a'] *= 2
+        with cute_testing.RaiseAssertor(TypeError):
+            bag['a'] /= 2
         with cute_testing.RaiseAssertor(TypeError):
             bag['a'] //= 2
         with cute_testing.RaiseAssertor(TypeError):
@@ -638,6 +667,12 @@ class BaseFrozenBagTestCase(BaseBagTestCase):
         assert bag == bag_reference + bag_reference + bag_reference
         assert bag is not bag_reference
         
+        # We only allow floor division on bags, not regular divison, because a
+        # decimal bag is unheard of.
+        bag = bag_reference
+        with cute_testing.RaiseAssertor(TypeError):
+            bag /= 2
+        
         bag = bag_reference
         bag //= 3
         assert bag == self.bag_type('a')
