@@ -1,4 +1,4 @@
-# Copyright 2009-2014 Ram Rachum.
+# Copyright 2009-2015 Ram Rachum.
 # This program is distributed under the MIT license.
 
 '''Testing module for `random_tools.shuffled`.'''
@@ -19,4 +19,7 @@ def test():
     assert my_range != shuffled_list
     
     # ...And the original list was not changed.
-    assert my_range == range(50)
\ No newline at end of file
+    assert my_range == list(range(50))
+    
+    # Immutable sequences work too:
+    assert set(random_tools.shuffled((1, 2, 3))) == {1, 2, 3}
\ No newline at end of file
